@@ -2,12 +2,17 @@
 Serializers for CSV operation data.
 """
 
+import logging
+
 import simplejson as json
 from django.contrib.auth import get_user_model
+from django.utils.translation import ugettext as _
 from rest_framework import serializers
 
 from .models import CSVOperation
 
+logger = logging.getLogger(__name__)
+
 
 class CSVOperationDataSerializer(serializers.Serializer):  # pylint: disable=abstract-method
     """
@@ -16,6 +21,7 @@ class CSVOperationDataSerializer(serializers.Serializer):  # pylint: disable=abs
     total_rows = serializers.IntegerField()
     processed_rows = serializers.IntegerField()
     saved_rows = serializers.IntegerField()
+    error_message = serializers.CharField(required=False)
 
 
 class CSVOperationSerializer(serializers.ModelSerializer):
@@ -38,5 +44,25 @@ class CSVOperationSerializer(serializers.ModelSerializer):
         return queryset.select_related('user')
 
     def get_data(self, operation):
-        data = json.load(operation.data)
-        return CSVOperationDataSerializer(data).data
+        """
+        Get data
+        """
+        try:
+            data = json.load(operation.data)
+        except (FileNotFoundError, ValueError):
+            msg = _('Failed to retrieve file.')
+
+            logger.error(
+                'Failed to retrieve operation data for operation %s course %s',
+                operation.id,
+                operation.unique_id
+            )
+            data = {
+                "total_rows": 0,
+                "processed_rows": 0,
+                "saved_rows": 0,
+                "error_message": msg
+            }
+        finally:
+            result = CSVOperationDataSerializer(data).data
+        return result
